.. django-logging-endpoint documentation master file, created by
   sphinx-quickstart on Tue Jan 27 12:04:31 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-logging-endpoint's documentation!
===================================================

Contents:

.. toctree::
   :maxdepth: 2

   topics/introduction
   topics/settings
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
